@@ -10,19 +10,10 @@ from dataclasses import dataclass
 from os.path import dirname, join, normpath, realpath
 from traceback import print_exc, print_exception
 from types import FrameType
-from typing import (
-    Any,
-    Callable,
-    List,
-    MutableMapping,
-    Optional,
-    Sequence,
-    Tuple,
-    Type,
-    Union,
-)
+from typing import Any, Callable, List, Optional, Sequence, Tuple, Type, Union
 
 from omegaconf import DictConfig, OmegaConf, read_write
+from omegaconf._utils import get_ref_type
 from omegaconf.errors import OmegaConfBaseException
 
 from hydra._internal.config_search_path_impl import ConfigSearchPathImpl
@@ -586,23 +577,16 @@ def _get_kwargs(config: Union[ObjectConf, DictConfig], **kwargs: Any) -> Any:
             warnings.warn(category=UserWarning, message=msg)
             params = config.params
         else:
-            params = OmegaConf.create()
-            for k, v in config.items():
-                if k != "_target_":
-                    params[k] = v
+            params = config
 
     assert isinstance(
-        params, MutableMapping
+        params, DictConfig
     ), f"Input config params are expected to be a mapping, found {type(config.params).__name__}"
 
-    if isinstance(config, DictConfig):
-        assert isinstance(params, DictConfig)
-        params._set_parent(config)
-
     config_overrides = {}
     passthrough = {}
     for k, v in kwargs.items():
-        if k in params:
+        if k in params and get_ref_type(params, k) is not Any:
             config_overrides[k] = v
         else:
             passthrough[k] = v
@@ -611,7 +595,12 @@ def _get_kwargs(config: Union[ObjectConf, DictConfig], **kwargs: Any) -> Any:
     with read_write(params):
         params.merge_with(config_overrides)
 
-    for k, v in params.items():
+    for k, v in params.items_ex(resolve=False):
+        if k == "_target_":
+            continue
+        final_kwargs[k] = v
+
+    for k, v in passthrough.items():
         final_kwargs[k] = v
 
     for k, v in passthrough.items():
