@@ -23,6 +23,8 @@ from tests import (
     IllegalType,
     NestingClass,
     Parameters,
+    UntypedPassthroughClass,
+    UntypedPassthroughConf,
 )
 
 objectconf_depreacted = (
@@ -139,6 +141,12 @@ def test_get_class(path: str, expected_type: type) -> None:
             AClass(a=10, b=20, c=30, d={"x": IllegalType()}),
             id="passthrough",
         ),
+        pytest.param(
+            UntypedPassthroughConf,
+            {"a": IllegalType(), "b": IllegalType()},
+            UntypedPassthroughClass(a=IllegalType(), b=IllegalType()),
+            id="untyped_passthrough",
+        ),
     ],
 )
 def test_class_instantiate(
